import React, { div } from "react";
import PropType from "prop-types";

export const Grid = ({
  container,
  item,
  spacingX,
  spacingY,
  children,
  size,
  style,
  ...props
}) => {
  if (container) {
    return (
      <div
        style={{
          marginLeft: -spacingX / 2,
          marginRight: -spacingX / 2,
          marginTop: spacingY / 2,
          marginBottom: spacingY / 2,
          display:"flex",
          flexWrap: "nowrap",
          flexDirection: "row",
        }}
        {...props}
      >
        {children &&
          children.map((c, i) =>
            React.cloneElement(c, { spacingX, spacingY, key: i }),
          )}
      </div>
    );
  }

  return (
    <div
      style={{
        paddingTop: spacingY / 2,
        paddingBottom: spacingY / 2,
        paddingLeft: spacingX / 2,
        paddingRight: spacingX / 2,
        flexBasis: `${(100 * size) / 12}%`,
      }}
      {...props}
    >
      {children}
    </div>
  );
};

Grid.defaultProps = {
  container: false,
  item: false,
  spacingX: 0,
  spacingY: 0,
  size: 12,
};

Grid.propTypes = {
  container: PropType.bool,
  item: PropType.bool,
  spacingX: PropType.number,
  spacingY: PropType.number,
  size: PropType.number,
};
