import React from "react";
import { Redirect } from "react-router-dom";

// Views
import { IntroductionScreen } from "./IntroductionScreen";
import { EndingScreen } from "./EndingScreen";
import { AvatarScreen } from "./AvatarScreen";
import { GameScreen } from "./GameScreen";

// Context
import { Attendance } from "../../services/classes/Attendance";

export class GameplayScreen extends React.Component {
  constructor(props) {
    super(props);

    this.state = {
      isLoaded: false,
      hasError: false,
      attendance: new Attendance(),
    };

    this.navigate = this.navigate.bind(this);
  }

  componentDidMount() {
    this.configureGame();
  }

  configureGame = () => {
    const gc = require(`../../data/case.json`);

    const attendance = new Attendance();
    attendance.setGameCase(gc);

    document.title = gc.title;

    this.setState({ isLoaded: true, attendance });
  };

  navigate(route, params) {
    this.props.history.push(route, {
      attendance: JSON.stringify(this.state.data),
      ...params,
    });
  }

  render() {
    const { isLoaded, hasError, attendance } = this.state;
    const rerender = () => this.forceUpdate();

    if (isLoaded && hasError) {
      return <Redirect to="/" />;
    }

    if (!attendance.avatar) {
      return (
        <AvatarScreen
          rerender={rerender}
          attendance={attendance}
          {...this.props}
        />
      );
    }

    if (!attendance.ready) {
      return (
        <IntroductionScreen
          rerender={rerender}
          attendance={attendance}
          caseId={this.state.attendance.case.data.id}
          {...this.props}
        />
      );
    }

    if (attendance.finalScore === null) {
      return (
        <GameScreen
          rerender={rerender}
          attendance={attendance}
          onNavigate={this.navigate}
          {...this.props}
        />
      );
    }

    return (
      <EndingScreen
        rerender={rerender}
        attendance={attendance}
        onNavigate={this.navigate}
        reloadCase={this.configureGame}
        {...this.props}
      />
    );
  }
}
